@@ -937,10 +937,12 @@ class VariableOsInstallPxeIp(Variable):
         self.help = "set IP address for PXE server"
 
     def get(self):
-        for ipaddr in ifilter(None, self.Get('os_install_net_ip')):
+        ips = self.Get('os_net_ip').split(',')
+        for ipaddr in ifilter(None, ips):
             return ipaddr
         else:
             return ""
 
     def choice(self):
-        return filter(None, self.Get('os_install_net_ip'))
+        ips = self.Get('os_net_ip').split(',')
+        return filter(None, ips)
